DriftWorkerHandler class

Constructors

DriftWorkerHandler({String id = driftStorageHandlerId, bool web = true, bool native = true})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable identifier used to match main/worker handler instances.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(WorkerHandlerContext context, SyncEngineConfig config) Future<Storage>
Creates a storage instance for the worker thread.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited